( cd usr/lib ; rm -rf libdbus-glib-1.so )
( cd usr/lib ; ln -sf libdbus-glib-1.so.2.1.0 libdbus-glib-1.so )
( cd usr/lib ; rm -rf libdbus-glib-1.so.2 )
( cd usr/lib ; ln -sf libdbus-glib-1.so.2.1.0 libdbus-glib-1.so.2 )
